@@ -38,21 +38,24 @@ allowed_cursor = ['alias', 'cell', 'grab', 'move', 'crosshair', 'context-menu',
                   'progress', 'text', 'wait', 'zoom-in', 'zoom-out']
 
 
-def basemap_to_tiles(bm, day='yesterday', **kwargs):
+def basemap_to_tiles(basemap, day='yesterday', **kwargs):
     # Format the URL with modisdate
     from datetime import date, timedelta
+
     if day == 'yesterday':
         yesterday = date.today() - timedelta(1)
         day = yesterday.strftime('%Y-%m-%d')
-    url = bm.get('url', '')
+
+    url = basemap.get('url', '')
     if url.count('%'):
         url = url % day
+
     return TileLayer(
         url=url,
-        max_zoom=bm.get('max_zoom', 19),
-        min_zoom=bm.get('min_zoom', 1),
-        attribution=bm.get('attribution', ''),
-        name=bm.get('name', ''),
+        max_zoom=basemap.get('max_zoom', 19),
+        min_zoom=basemap.get('min_zoom', 1),
+        attribution=basemap.get('attribution', ''),
+        name=basemap.get('name', ''),
         **kwargs
     )
 
@@ -876,11 +879,13 @@ class Map(DOMWidget, InteractMixin):
     crs = Enum(values=allowed_crs, default_value='EPSG3857').tag(sync=True)
 
     # Specification of the basemap
-    basemap = Dict(default_value=dict(
+    basemap = Union(
+        (Dict(), Instance(TileLayer)),
+        default_value=dict(
             url='https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
             max_zoom=19,
             attribution='Map data (c) <a href="https://openstreetmap.org">OpenStreetMap</a> contributors'
-        )).tag(sync=True, o=True)
+        ))
     modisdate = Unicode('yesterday').tag(sync=True)
 
     # Interaction options
@@ -933,7 +938,11 @@ class Map(DOMWidget, InteractMixin):
 
     @default('layers')
     def _default_layers(self):
-        return (basemap_to_tiles(self.basemap, self.modisdate, base=True),)
+        basemap = self.basemap if isinstance(self.basemap, TileLayer) else basemap_to_tiles(self.basemap, self.modisdate)
+
+        basemap.base = True
+
+        return (basemap, )
 
     bounds = Tuple(read_only=True)
     bounds_polygon = Tuple(read_only=True)
